CoverageAnalytics class

Comprehensive localization analytics and coverage tracking

Constructors

CoverageAnalytics({required String projectPath, bool verbose = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
projectPath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verbose bool
final

Methods

exportAnalyticsToJson(LocalizationAnalytics analytics, String outputPath) Future<void>
Exports analytics to JSON file
generateAnalytics({required List<NonLocalizedString> nonLocalizedStrings, required Map<String, List<String>> existingTranslations, required List<String> dartFiles}) Future<LocalizationAnalytics>
Generates comprehensive localization analytics
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited