AutoCodeConverter class

Automatic code converter that transforms hardcoded strings to localization calls

Constructors

AutoCodeConverter({required String projectPath, bool verbose = false, bool dryRun = false})

Properties

dryRun bool
final
hashCode int
The hash code for this object.
no setterinherited
projectPath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verbose bool
final

Methods

convertAllStrings(List<NonLocalizedString> nonLocalizedStrings) Future<ConversionResult>
Convert all non-localized strings to AppLocalizations calls
convertSpecificPattern({required String pattern, required String replacement, List<String>? fileExtensions}) Future<void>
Convert specific patterns with custom logic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited