ConversionResult class

Result of the conversion process

Constructors

ConversionResult({required List<CodeConversion> conversions, required List<String> failedConversions, required List<String> filesModified, required int totalStringsProcessed})

Properties

conversions List<CodeConversion>
final
failedConversions List<String>
final
filesModified List<String>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
successRate double
no setter
totalStringsProcessed int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited