FileConversionResult class

Result of converting a single file

Constructors

FileConversionResult({required String filePath, required List<CodeConversion> conversions, required String originalContent, required String modifiedContent})

Properties

conversions List<CodeConversion>
final
filePath String
final
hashCode int
The hash code for this object.
no setterinherited
modifiedContent String
final
originalContent String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited