EnhancedLocalizationChecker class
Enhanced localization checker with end-to-end automation capabilities
Constructors
- EnhancedLocalizationChecker({required LocalizationCheckerConfig config, required EnhancedLocalizationConfig enhancedConfig, bool verbose = false})
Properties
- config → LocalizationCheckerConfig
-
final
- enhancedConfig → EnhancedLocalizationConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verbose → bool
-
final
Methods
-
exportComprehensiveReport(
{required EnhancedLocalizationResult result, required String outputPath}) → Future< void> - Exports comprehensive report
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
runComplete(
{bool generateArb = true, bool autoTranslate = false, bool generateAnalytics = true, bool generateCode = false, String? arbOutputDir}) → Future< EnhancedLocalizationResult> - Runs the complete enhanced localization checking and automation process
-
runIncremental(
{required List< String> changedFiles, String? baselineReportPath}) → Future<IncrementalCheckResult> - Runs incremental checking for continuous integration
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited