EnhancedLocalizationResult class

Result of enhanced localization checking

Constructors

EnhancedLocalizationResult({required List<NonLocalizedString> nonLocalizedStrings, LocalizationAnalytics? analytics, Map<String, Map<String, dynamic>>? translatedArbs, required List<String> generatedFiles})

Properties

analytics LocalizationAnalytics?
final
generatedFiles List<String>
final
hashCode int
The hash code for this object.
no setterinherited
nonLocalizedStrings List<NonLocalizedString>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translatedArbs Map<String, Map<String, dynamic>>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited