ArbGenerator class

Constructors

ArbGenerator({required String outputDirectory, bool verbose = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
outputDirectory String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verbose bool
final

Methods

generateMultiLanguageArbs(List<NonLocalizedString> nonLocalizedStrings, List<String> languages) Future<void>
Generate multiple language ARB files
generateSmartArb(List<NonLocalizedString> nonLocalizedStrings) Future<void>
Smart ARB generation with intelligent merging
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited