FileCoverage class

File-level coverage analysis

Constructors

FileCoverage({required String filePath, required int totalStrings, required int localizedStrings, required int nonLocalizedStrings, required double coveragePercentage, required List<String> issues})

Properties

coveragePercentage double
final
filePath String
final
hashCode int
The hash code for this object.
no setterinherited
issues List<String>
final
localizedStrings int
final
nonLocalizedStrings int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalStrings int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited