NonLocalizedString class

Constructors

NonLocalizedString({required String filePath, required int lineNumber, int columnNumber = 0, required String content, required List<String> context, required int offset, required int length, List<String> variables = const [], String? parentNode, String? constructorName, String? argumentName})

Properties

argumentName String?
final
columnNumber int
final
constructorName String?
final
content String
final
context List<String>
final
filePath String
final
hashCode int
The hash code for this object.
no setterinherited
length int
final
lineNumber int
final
offset int
final
parentNode String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variables List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited