StringLiteralInfo class

Constructors

StringLiteralInfo({required String content, required int lineNumber, int columnNumber = 0, bool isInterpolated = false, String? parentNode, String? constructorName, String? argumentName, required int offset, required int length, List<String> variables = const []})

Properties

argumentName String?
final
columnNumber int
final
constructorName String?
final
content String
final
hashCode int
The hash code for this object.
no setterinherited
isInterpolated bool
final
length int
final
lineNumber int
final
offset int
final
parentNode String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variables List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited