CodeConversion class
Details of a single code conversion
Constructors
- CodeConversion({required String originalString, required String localizationKey, required String localizationCall, required String filePath, required int lineNumber, required String pattern, required ConversionType conversionType})
Properties
- conversionType → ConversionType
-
final
- filePath → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lineNumber → int
-
final
- localizationCall → String
-
final
- localizationKey → String
-
final
- originalString → String
-
final
- pattern → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited