LocalizationCodeGenerator class

Automated code generator for Flutter localization setup

Constructors

LocalizationCodeGenerator({required String projectPath, required String outputDirectory, bool verbose = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
outputDirectory String
final
projectPath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verbose bool
final

Methods

generateCompleteSetup({required List<String> supportedLanguages, required Map<String, Map<String, dynamic>> translations, bool generateExtensions = true, bool updatePubspec = true, bool generateL10nYaml = true}) Future<void>
Generates complete localization setup for a Flutter project
generateDocumentation() Future<void>
Generates comprehensive documentation for the localization package
generateTranslationService({required List<String> supportedLanguages, bool includeFreeServices = true, bool includeTemplateApproach = true}) Future<void>
Generates a flexible translation service supporting multiple backends
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited