IncrementalCheckResult class
Result of incremental checking
Constructors
-
IncrementalCheckResult({required List<
NonLocalizedString> newIssues, required List<NonLocalizedString> resolvedIssues, required List<String> changedFiles})
Properties
-
changedFiles
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
newIssues
→ List<
NonLocalizedString> -
final
-
resolvedIssues
→ List<
NonLocalizedString> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited