ComplexityAnalysis class
Complexity analysis for localization requirements
Constructors
Properties
- complexityScore → int
-
final
- complexStrings → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- interpolatedStrings → int
-
final
- longStrings → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- simpleStrings → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited