EnhancedLocalizationConfig class
Configuration for enhanced localization features
Constructors
-
EnhancedLocalizationConfig({bool enableAutoTranslation = false, List<
String> targetLanguages = const ['es', 'fr', 'de', 'it'], String translationApiKey = '', String translationProvider = 'google', bool enableAnalytics = true, bool enableCodeGeneration = false, String outputDirectory = 'lib/l10n', Map<String, dynamic> customSettings = const {}})
Properties
-
customSettings
→ Map<
String, dynamic> -
final
- enableAnalytics → bool
-
final
- enableAutoTranslation → bool
-
final
- enableCodeGeneration → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- outputDirectory → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
targetLanguages
→ List<
String> -
final
- translationApiKey → String
-
final
- translationProvider → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited