LocalizationAnalytics class
Comprehensive localization analytics data
Constructors
-
LocalizationAnalytics({required int totalStringsFound, required int localizedStrings, required int nonLocalizedStrings, required Map<
String, List< duplicateStrings, required List<NonLocalizedString> >String> unusedTranslations, required double coveragePercentage, required Map<String, FileCoverage> filesCoverage, required int complexityScore, required List<String> recommendations, required String summary})
Properties
- complexityScore → int
-
final
- coveragePercentage → double
-
final
-
duplicateStrings
→ Map<
String, List< NonLocalizedString> > -
final
-
filesCoverage
→ Map<
String, FileCoverage> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- localizedStrings → int
-
final
- nonLocalizedStrings → int
-
final
-
recommendations
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- summary → String
-
final
- totalStringsFound → int
-
final
-
unusedTranslations
→ List<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited