StringLiteralInfo class
Constructors
Properties
- argumentName → String?
-
final
- columnNumber → int
-
final
- constructorName → String?
-
final
- content → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInterpolated → bool
-
final
- length → int
-
final
- lineNumber → int
-
final
- offset → int
-
final
- parentNode → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
variables
→ List<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited